@@ -165,10 +165,11 @@ struct information {
   double uptime;
 
   /* memory information in kilobytes */
-  unsigned long long mem, memwithbuffers, memeasyfree, memfree, memmax,
-      memdirty, legacymem;
+  unsigned long long mem, memwithbuffers, memavail, memeasyfree, memfree,
+      memmax, memdirty, shmem, legacymem, memactive, meminactive, memwired,
+      memlaundry;
   unsigned long long swap, swapfree, swapmax;
-  unsigned long long bufmem, buffers, cached;
+  unsigned long long bufmem, buffers, cached, free_bufcache;
 
   unsigned short procs;
   unsigned short run_procs;
@@ -292,7 +293,15 @@ extern conky::range_config_setting<double> update_interval;
 extern conky::range_config_setting<double> update_interval_on_battery;
 double active_update_interval();
 
+extern conky::simple_config_setting<bool> show_graph_scale;
+extern conky::simple_config_setting<bool> show_graph_range;
+extern conky::simple_config_setting<int> gap_x;
+extern conky::simple_config_setting<int> gap_y;
+extern conky::simple_config_setting<bool> draw_borders;
+extern conky::simple_config_setting<bool> draw_graph_borders;
 extern conky::range_config_setting<char> stippled_borders;
+extern conky::simple_config_setting<bool> draw_shades;
+extern conky::simple_config_setting<bool> draw_outline;
 
 void set_current_text_color(long colour);
 long get_current_text_color(void);
@@ -301,7 +310,7 @@ void set_updatereset(int);
 int get_updatereset(void);
 int get_total_updates(void);
 
-int xft_dpi_scale(int value);
+int dpi_scale(int value);
 
 int get_saved_coordinates_x(int);
 int get_saved_coordinates_y(int);
@@ -322,10 +331,13 @@ void extract_object_args_to_sub(struct text_object *, const char *);
 
 void generate_text_internal(char *, int, struct text_object);
 
+void update_text_area();
+void draw_stuff();
+
 int percent_print(char *, int, unsigned);
 void human_readable(long long, char *, int);
 
-#ifdef BUILD_X11
+#ifdef BUILD_GUI
 
 /* UTF-8 */
 extern conky::simple_config_setting<bool> utf8_mode;
@@ -380,4 +392,7 @@ extern char **argv_copy;
 extern const char *getopt_string;
 extern const struct option longopts[];
 
+extern conky::simple_config_setting<bool> out_to_stdout;
+extern conky::simple_config_setting<bool> out_to_stderr;
+
 #endif /* _conky_h_ */
