@@ -9,7 +9,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2021 Brenden Matthews, Philip Kovacs, et. al.
  * (see AUTHORS)
  * All rights reserved.
  *
@@ -153,7 +153,7 @@ static void print_diskio_dir(struct text_object *obj, int dir, char *p,
 
   /* TODO: move this correction from kB to kB/s elsewhere
    * (or get rid of it??) */
-  human_readable((val / active_update_interval()) * 1024LL, p, p_max_size);
+  human_readable(val / active_update_interval(), p, p_max_size);
 }
 
 void print_diskio(struct text_object *obj, char *p, unsigned int p_max_size) {
@@ -170,7 +170,7 @@ void print_diskio_write(struct text_object *obj, char *p,
   print_diskio_dir(obj, 1, p, p_max_size);
 }
 
-#ifdef BUILD_X11
+#ifdef BUILD_GUI
 void parse_diskiograph_arg(struct text_object *obj, const char *arg) {
   char *buf = nullptr;
   buf = scan_graph(obj, arg, 0);
@@ -196,7 +196,7 @@ double diskiographval_write(struct text_object *obj) {
 
   return (diskio != nullptr ? diskio->current_write : 0);
 }
-#endif /* BUILD_X11 */
+#endif /* BUILD_GUI */
 
 void update_diskio_values(struct diskio_stat *ds, unsigned int reads,
                           unsigned int writes) {
@@ -219,9 +219,9 @@ void update_diskio_values(struct diskio_stat *ds, unsigned int reads,
   /* compute averages */
   int samples = diskio_avg_samples.get(*state);
   for (i = 0; i < samples; i++) {
-    sum += ds->sample[i];
-    sum_r += ds->sample_read[i];
-    sum_w += ds->sample_write[i];
+    sum += ds->sample[i] * 1024LL;
+    sum_r += ds->sample_read[i] * 1024LL;
+    sum_w += ds->sample_write[i] * 1024LL;
   }
   ds->current = sum / static_cast<double>(samples);
   ds->current_read = sum_r / static_cast<double>(samples);
